@@ -42,7 +42,7 @@ def SubVector(StartEnd, Vector):
     Extract a sub-vector based on start and end values. The output are the indices in the input vector.
     '''
     Above = Vector >= StartEnd[0]
-    Below = Vector < StartEnd[1]
+    Below = Vector <= StartEnd[1]
     Select = np.logical_and(Above, Below)
     return np.arange(len(Vector))[Select]
     
